@@ -5,13 +5,13 @@ pub fn excel_cmd() -> Command {
         arg!(--sheet),
         arg!(--"header-row"),
         arg!(--metadata),
+        arg!(--table),
+        arg!(--range),
         arg!(--"error-format"),
         arg!(--flexible),
         arg!(--trim),
         arg!(--"date-format"),
         arg!(--"keep-zero-time"),
-        arg!(--table),
-        arg!(--"range"),
         arg!(--jobs),
         arg!(--output),
         arg!(--delimiter),
