@@ -2,36 +2,45 @@ use clap::{arg, Command};
 
 pub fn joinp_cmd() -> Command {
     Command::new("joinp").args([
-        arg!(--"ignore-case"),
         arg!(--left),
         arg!(--"left-anti"),
         arg!(--"left-semi"),
         arg!(--right),
+        arg!(--"right-anti"),
+        arg!(--"right-semi"),
         arg!(--full),
         arg!(--cross),
+        arg!(--"non-equi"),
         arg!(--coalesce),
         arg!(--"filter-left"),
         arg!(--"filter-right"),
         arg!(--validate),
+        arg!(--"maintain-order"),
         arg!(--nulls),
         arg!(--streaming),
         arg!(--"try-parsedates"),
         arg!(--"infer-len"),
+        arg!(--"cache-schema"),
         arg!(--"low-memory"),
         arg!(--"no-optimizations"),
         arg!(--"ignore-errors"),
         arg!(--"decimal-comma"),
         arg!(--asof),
+        arg!(--"no-sort"),
         arg!(--"left_by"),
         arg!(--"right_by"),
         arg!(--strategy),
         arg!(--tolerance),
+        arg!(--"allow-exact-matches"),
         arg!(--"sql-filter"),
         arg!(--"datetime-format"),
         arg!(--"date-format"),
         arg!(--"time-format"),
         arg!(--"float-precision"),
         arg!(--"null-value"),
+        arg!(--"ignore-case"),
+        arg!(--"ignore-leading-zeros"),
+        arg!(--"norm-unicode"),
         arg!(--output),
         arg!(--delimiter),
         arg!(--quiet),
