@@ -10,6 +10,9 @@ pub fn lens_cmd() -> Command {
         arg!(--find),
         arg!(--"ignore-case"),
         arg!(--"freeze-columns"),
+        arg!(--monochrome),
+        arg!(--"wrap-mode"),
+        arg!(--prompt),
         arg!(--"echo-column"),
         arg!(--debug),
     ])
