@@ -23,6 +23,7 @@ pub mod fmt;
 pub mod foreach;
 pub mod frequency;
 pub mod geocode;
+pub mod geoconvert;
 pub mod headers;
 pub mod index;
 pub mod input;
@@ -33,6 +34,7 @@ pub mod jsonl;
 pub mod lens;
 pub mod luau;
 pub mod partition;
+pub mod pivotp;
 pub mod pro;
 pub mod prompt;
 pub mod pseudo;
