@@ -8,6 +8,9 @@ pub fn split_cmd() -> Command {
         arg!(--jobs),
         arg!(--filename),
         arg!(--pad),
+        arg!(--filter),
+        arg!(--"filter-cleanup"),
+        arg!(--"filter-ignore-errors"),
         arg!(--"no-headers"),
         arg!(--delimiter),
         arg!(--quiet),
