@@ -42,7 +42,7 @@
 arg_pat="$1"
 
 # the version of this script
-bm_version=6.8.0
+bm_version=7.1.0
 
 # CONFIGURABLE VARIABLES ---------------------------------------
 # change as needed to reflect your environment/workloads
@@ -620,6 +620,7 @@ run pseudo "$qsv_bin" pseudo \'Unique Key\' "$data"
 run pseudo_formatstr "$qsv_bin" pseudo \'Unique Key\' --formatstr 'ID-{}' --increment 5 "$data"
 run rename "$qsv_bin" rename \'unique_key,created_date,closed_date,agency,agency_name,complaint_type,descriptor,loctype,zip,addr1,street,xstreet1,xstreet2,inter1,inter2,addrtype,city,landmark,facility_type,status,due_date,res_desc,res_act_date,comm_board,bbl,boro,xcoord,ycoord,opendata_type,parkname,parkboro,vehtype,taxi_boro,taxi_loc,bridge_hwy_name,bridge_hwy_dir,ramp,bridge_hwy_seg,lat,long,loc\' "$data"
 run replace "$qsv_bin" replace \'zip\' \'postal\' "$data"
+run --index replace_indexed "$qsv_bin" replace \'zip\' \'postal\' "$data"
 run reverse "$qsv_bin" reverse "$data"
 run --index reverse_index "$qsv_bin" reverse "$data"
 run safenames "$qsv_bin" safenames "$data"
@@ -653,9 +654,11 @@ run search_file_case_sensitive "$qsv_bin" search "'us'" "$data"
 run search_file_case_sensitive_unicode "$qsv_bin" search --unicode "'us'" "$data"
 run search_file_flag "$qsv_bin" search "'(?i)us'" "$data" --flag flagged
 run search_file_flag_matchonly "$qsv_bin" search "'(?i)us'" "$data" --flag M
+run --index search_index "$qsv_bin" search -s \'Agency Name\' "'(?i)us'" "$data"
 run searchset "$qsv_bin" searchset searchset_patterns.txt "$data"
 run searchset_ignorecase "$qsv_bin" searchset --ignore-case searchset_patterns.txt "$data"
 run searchset_unicode "$qsv_bin" searchset searchset_patterns_unicode.txt --unicode "$data"
+run --index searchset_index "$qsv_bin" searchset searchset_patterns.txt "$data"
 run select "$qsv_bin" select \'Agency,Community Board\' "$data"
 run select_regex "$qsv_bin" select /^L/ "$data"
 run slice_one_middle "$qsv_bin" slice -i 500000 "$data"
