@@ -11,48 +11,48 @@ NOTE: diff does not support stdin. A file path is required for both arguments.
       To check if a CSV has unique primary key values, use `qsv extdedup`
       with the same key columns using the `--select` option:
 
-         qsv extdedup --select keycol data.csv --no-output
+         $ qsv extdedup --select keycol data.csv --no-output
 
       The duplicate count will be printed to stderr.
 
 Examples:
 
 Find the difference between two CSVs:
-    qsv diff left.csv right.csv
+    $ qsv diff left.csv right.csv
 
 Find the difference between two CSVs. The right CSV has no headers:
-    qsv diff left.csv --no-headers-right right-noheaders.csv
+    $ qsv diff left.csv --no-headers-right right-noheaders.csv
 
 Find the difference between two CSVs. The left CSV uses a tab as the delimiter:
-    qsv diff --delimiter-left '\t' left.csv right-tab.tsv
+    $ qsv diff --delimiter-left '\t' left.csv right-tab.tsv
     # or ';' as the delimiter
-    qsv diff --delimiter-left ';' left.csv right-semicolon.csv
+    $ qsv diff --delimiter-left ';' left.csv right-semicolon.csv
 
 Find the difference between two CSVs. The output CSV uses a tab as the delimiter
 and is written to a file:
-    qsv diff -o diff-tab.tsv --delimiter-output '\t' left.csv right.csv
+    $ qsv diff -o diff-tab.tsv --delimiter-output '\t' left.csv right.csv
     # or ';' as the delimiter
-    qsv diff -o diff-semicolon.csv --delimiter-output ';' left.csv right.csv
+    $ qsv diff -o diff-semicolon.csv --delimiter-output ';' left.csv right.csv
 
 Find the difference between two CSVs, comparing records that have the same values
 in the first two columns:
-    qsv diff --key 0,1 left.csv right.csv
+    $ qsv diff --key 0,1 left.csv right.csv
 
 Find the difference between two CSVs, comparing records that have the same values
 in the first two columns and sort the result by the first two columns:
-    qsv diff -k 0,1 --sort-columns 0,1 left.csv right.csv
+    $ qsv diff -k 0,1 --sort-columns 0,1 left.csv right.csv
 
 Find the difference between two CSVs, but do not output equal field values
 in the result (equal field values are replaced with the empty string). Key
 field values _will_ appear in the output:
-    qsv diff --drop-equal-fields left.csv right.csv
+    $ qsv diff --drop-equal-fields left.csv right.csv
 
 Find the difference between two CSVs, but do not output headers in the result:
-    qsv diff --no-headers-output left.csv right.csv
+    $ qsv diff --no-headers-output left.csv right.csv
 
 Find the difference between two CSVs. Both CSVs have no headers, but the result should have
 headers, so generic headers will be used in the form of: _col_1, _col_2, etc.:
-    qsv diff --no-headers-left --no-headers-right left.csv right.csv
+    $ qsv diff --no-headers-left --no-headers-right left.csv right.csv
 
 For more examples, see https://github.com/dathere/qsv/blob/master/tests/test_diff.rs
 
@@ -81,7 +81,7 @@ diff options:
     -k, --key <arg...>          The column indices that uniquely identify a record
                                 as a comma separated list of 0-based indices, e.g. 0,1,2
                                 or column names, e.g. name,age.
-                                Note that when selecting columns by name, only the 
+                                Note that when selecting columns by name, only the
                                 left CSV's headers are used to match the column names
                                 and it is assumed that the right CSV has the same
                                 selected column names in the same order as the left CSV.
@@ -94,7 +94,7 @@ diff options:
                                 but have different content) will always be kept together
                                 in the sorted diff result and so won't be sorted
                                 independently from each other.
-                                Note that when selecting columns by name, only the 
+                                Note that when selecting columns by name, only the
                                 left CSV's headers are used to match the column names
                                 and it is assumed that the right CSV has the same
                                 selected column names in the same order as the left CSV.
