@@ -942,8 +942,7 @@ pub fn run(argv: &[&str]) -> CliResult<()> {
     };
 
     // amortize allocations
-    let mut record = csv::StringRecord::with_capacity(500, col_count);
-    let mut trimmed_record = csv::StringRecord::with_capacity(500, col_count);
+    let mut record = csv::StringRecord::with_capacity(512, col_count);
 
     // get headers
     info!("exporting sheet ({sheet})...");
@@ -961,6 +960,7 @@ pub fn run(argv: &[&str]) -> CliResult<()> {
 
     if trim {
         record.trim();
+        let mut trimmed_record = csv::StringRecord::with_capacity(512, col_count);
         record.iter().for_each(|field| {
             if field.contains('\n') {
                 trimmed_record.push_field(&field.replace('\n', " "));
@@ -1003,48 +1003,46 @@ pub fn run(argv: &[&str]) -> CliResult<()> {
     rows.par_chunks(chunk_size)
         .map(|chunk| {
             // amortize allocations
-            let mut record = csv::StringRecord::with_capacity(500, col_count);
+            let mut record = csv::StringRecord::with_capacity(512, col_count);
             let mut trimmed_record = if trim {
-                csv::StringRecord::with_capacity(500, col_count)
+                csv::StringRecord::with_capacity(512, col_count)
             } else {
                 csv::StringRecord::new()
             };
-            let mut float_val;
+
             let mut work_date;
             let mut error_buffer = String::new();
             let mut formatted_date = String::new();
 
             let mut processed_chunk: Vec<csv::StringRecord> = Vec::with_capacity(chunk_size);
-            let mut col_idx = 0_u32;
 
             let mut cell_formula;
             let mut itoa_buf = itoa::Buffer::new();
             let mut ryu_buf = ryu::Buffer::new();
 
             for (row_idx, row) in chunk {
-                for cell in *row {
-                    match *cell {
+                for (col_idx, cell) in row.iter().enumerate() {
+                    match cell {
                         Data::Empty => record.push_field(""),
-                        Data::String(ref s) => record.push_field(s),
-                        Data::Int(ref i) => record.push_field(itoa_buf.format(*i)),
-                        Data::Float(ref f) => {
-                            float_val = *f;
+                        Data::String(s) => record.push_field(s),
+                        Data::Int(i) => record.push_field(itoa_buf.format(*i)),
+                        Data::Float(float_val) => {
                             // push the ryu-formatted float value if its
                             // not an integer or the candidate
                             // integer is too big or too small to be an i64
                             #[allow(clippy::cast_precision_loss)]
                             if float_val.fract().abs() > f64::EPSILON
-                                || float_val > i64::MAX as f64
-                                || float_val < i64::MIN as f64
+                                || *float_val > i64::MAX as f64
+                                || *float_val < i64::MIN as f64
                             {
-                                record.push_field(ryu_buf.format_finite(float_val));
+                                record.push_field(ryu_buf.format_finite(*float_val));
                             } else {
                                 // its an i64 integer. We can't use ryu to format it, because it
                                 // will be formatted as a float (have a ".0"). So we use itoa.
-                                record.push_field(itoa_buf.format(float_val as i64));
+                                record.push_field(itoa_buf.format(*float_val as i64));
                             }
                         },
-                        Data::DateTime(ref edt) => {
+                        Data::DateTime(edt) => {
                             if edt.is_datetime() {
                                 if let Some(dt) = edt.as_datetime() {
                                     if no_date_format {
@@ -1088,12 +1086,12 @@ pub fn run(argv: &[&str]) -> CliResult<()> {
 
                             record.push_field(&work_date);
                         },
-                        Data::Bool(ref b) => {
+                        Data::Bool(b) => {
                             record.push_field(if *b { "true" } else { "false" });
                         },
-                        Data::DateTimeIso(ref dt) => record.push_field(dt),
-                        Data::DurationIso(ref d) => record.push_field(d),
-                        Data::Error(ref e) => {
+                        Data::DateTimeIso(dt) => record.push_field(dt),
+                        Data::DurationIso(d) => record.push_field(d),
+                        Data::Error(e) => {
                             // safety: the unwraps in this block are safe because the format strings
                             // are hardcoded and are guaranteed to be correct
                             error_buffer.clear();
@@ -1101,7 +1099,7 @@ pub fn run(argv: &[&str]) -> CliResult<()> {
                                 write!(error_buffer, "{e}").unwrap();
                             } else {
                                 cell_formula = sheet_formulas
-                                    .get_value((*row_idx, col_idx))
+                                    .get_value((*row_idx, col_idx as u32))
                                     .unwrap_or(&formula_get_value_error);
                                 if error_format == ErrorFormat::Formula {
                                     write!(error_buffer, "#={cell_formula}").unwrap();
@@ -1113,7 +1111,6 @@ pub fn run(argv: &[&str]) -> CliResult<()> {
                             record.push_field(error_buffer.as_str());
                         },
                     }
-                    col_idx += 1;
                 }
 
                 if trim {
