@@ -26,35 +26,35 @@ The files are written to the directory given with the name '{start}.csv',
 where {start} is the index of the first record of the chunk (starting at 0).
 
 Examples:
-    qsv split outdir --size 100 --filename chunk_{}.csv input.csv
-    # This will create files with names like chunk_0.csv, chunk_100.csv, etc.
-    # in the directory 'outdir', creating the directory if it does not exist.
+  $ qsv split outdir --size 100 --filename chunk_{}.csv input.csv
+  # This will create files with names like chunk_0.csv, chunk_100.csv, etc.
+  # in the directory 'outdir', creating the directory if it does not exist.
 
-    qsv split outdir/subdir -s 100 --filename chunk_{}.csv --pad 5 input.csv
-    # This will create files with names like chunk_00000.csv, chunk_00100.csv, etc.
-    # in the directory 'outdir/subdir', creating the directories if they do not exist.
+  $ qsv split outdir/subdir -s 100 --filename chunk_{}.csv --pad 5 input.csv
+  # This will create files with names like chunk_00000.csv, chunk_00100.csv, etc.
+  # in the directory 'outdir/subdir', creating the directories if they do not exist.
 
-    qsv split . -s 100 input.csv
-    # This will create files like 0.csv, 100.csv, etc. in the current directory.
+  $ qsv split . -s 100 input.csv
+  # This will create files like 0.csv, 100.csv, etc. in the current directory.
 
-    qsv split outdir --kb-size 1000 input.csv
-    # This will create files with names like 0.csv, 994.csv, etc. in the directory
-    # 'outdir', creating the directory if it does not exist. Each file will be close
-    # to 1000KB in size.
+  $ qsv split outdir --kb-size 1000 input.csv
+  # This will create files with names like 0.csv, 994.csv, etc. in the directory
+  # 'outdir', creating the directory if it does not exist. Each file will be close
+  # to 1000KB in size.
 
-    cat in.csv | qsv split mysplitoutput -s 1000
+  $ cat in.csv | qsv split mysplitoutput -s 1000
 
-    qsv split outdir --chunks 10 input.csv
+  $ qsv split outdir --chunks 10 input.csv
 
-    qsv split splitoutdir -c 10 -j 4 input.csv
+  $ qsv split splitoutdir -c 10 -j 4 input.csv
 
-    qsv split outdir -s 100 --filter "gzip $FILE" input.csv
-    # This will create files with names like 0.csv, 100.csv, etc. in the directory
-    # 'outdir', and then run the command "gzip" on each chunk.
+  $ qsv split outdir -s 100 --filter "gzip $FILE" input.csv
+  # This will create files with names like 0.csv, 100.csv, etc. in the directory
+  # 'outdir', and then run the command "gzip" on each chunk.
 
-    qsv split outdir --filter "powershell Compress-Archive -Path $FILE -Destination {}.zip" input.csv
-    # WINDOWS: This will create files with names like 0.zip, 100.zip, etc. in the directory
-    # 'outdir', and then run the command "Compress-Archive" on each chunk.
+  $ qsv split outdir --filter "powershell Compress-Archive -Path $FILE -Destination {}.zip" input.csv
+  # WINDOWS: This will create files with names like 0.zip, 100.zip, etc. in the directory
+  # 'outdir', and then run the command "Compress-Archive" on each chunk.
 
 For more examples, see https://github.com/dathere/qsv/blob/master/tests/test_split.rs.
 
@@ -125,7 +125,7 @@ Common options:
 use std::{fs, io, path::Path, process::Command};
 
 use dunce;
-use log::{debug, error};
+use log::debug;
 use rayon::iter::{IntoParallelIterator, ParallelIterator};
 use serde::Deserialize;
 
