@@ -287,16 +287,10 @@ use std::{
 };
 
 use polars::{
-    datatypes::PlSmallStr,
     io::avro::{AvroWriter, Compression as AvroCompression},
-    prelude::{
-        Arc, CsvWriter, DataFrame, GzipLevel, IpcCompression, IpcWriter, JsonFormat, JsonWriter,
-        LazyCsvReader, LazyFileListReader, NullValues, OptFlags, ParquetCompression, ParquetWriter,
-        Schema, SerWriter, StatisticsOptions, ZstdLevel,
-    },
+    prelude::*,
     sql::SQLContext,
 };
-use polars_utils::plpath::PlPath;
 use regex::Regex;
 use serde::Deserialize;
 
