@@ -6,14 +6,14 @@ This command processes each row of the CSV file, making the column values availa
 Each row is rendered using the template. Column headers become variable names, with non-alphanumeric
 characters converted to underscore (_).
 
-Templates use Jinja2 syntax (https://jinja.palletsprojects.com/en/stable/templates/) 
+Templates use Jinja2 syntax (https://jinja.palletsprojects.com/en/stable/templates/)
 and can access an extensive library of built-in filters/functions, with additional ones
 from minijinja_contrib https://docs.rs/minijinja-contrib/latest/minijinja_contrib/.
 Additional qsv custom filters are also documented at the end of this file.
 
 If the <outdir> argument is specified, it will create a file for each row in <outdir>, with
 the filename rendered using --outfilename option.
-Otherwise, ALL the rendered rows will be sent to STDOUT or the designated --output. 
+Otherwise, ALL the rendered rows will be sent to STDOUT or the designated --output.
 
 Example:
 data.csv:
@@ -49,7 +49,7 @@ template.tpl
     {% endif %}
     Status: {% if active|to_bool %}Active{% else %}Inactive{% endif %}
 
-qsv template --template-file template.tpl data.csv
+  $ qsv template --template-file template.tpl data.csv
 
 For more examples, see https://github.com/dathere/qsv/blob/master/tests/test_template.rs.
 For a relatively complex MiniJinja template, see https://github.com/dathere/qsv/blob/master/scripts/template.tpl
@@ -78,7 +78,7 @@ template options:
                                 The JSON properties can be accessed in templates using the "qsv_g"
                                 namespace (e.g. {{qsv_g.school_name}}, {{qsv_g.year}}).
                                 This allows sharing common values across all template renders.
-    --outfilename <str>         MiniJinja template string to use to create the filename of the output 
+    --outfilename <str>         MiniJinja template string to use to create the filename of the output
                                 files to write to <outdir>. If set to just QSV_ROWNO, the filestem
                                 is set to the current rowno of the record, padded with leading
                                 zeroes, with the ".txt" extension (e.g. 001.txt, 002.txt, etc.)
@@ -276,11 +276,18 @@ pub fn run(argv: &[&str]) -> CliResult<()> {
     let mut rdr = rconfig.reader()?;
 
     // Get width of rowcount for padding leading zeroes and early return
-    let rowcount = util::count_rows(&rconfig)?;
-    if rconfig.no_headers && rowcount == 1 {
-        return Ok(());
-    }
-    let width = rowcount.to_string().len();
+    // For stdin, we can't pre-count rows as it would consume the stream
+    let (rowcount, width) = if rconfig.is_stdin() {
+        // For stdin, we'll use a reasonable default width and skip early return check
+        (0, 6) // Default width of 6 for up to 999,999 rows
+    } else {
+        let rowcount = util::count_rows(&rconfig)?;
+        if rconfig.no_headers && rowcount == 1 {
+            return Ok(());
+        }
+        let width = rowcount.to_string().len();
+        (rowcount, width)
+    };
 
     // read headers - the headers are used as MiniJinja variables in the template
     let headers = if args.flag_no_headers {
