@@ -277,7 +277,6 @@ use indicatif::HumanCount;
 use indicatif::{ProgressBar, ProgressDrawTarget};
 use jsonschema::{
     Keyword, PatternOptions, ValidationError, Validator,
-    output::BasicOutput,
     paths::{LazyLocation, Location},
 };
 use log::debug;
@@ -1076,49 +1075,29 @@ pub fn run(argv: &[&str]) -> CliResult<()> {
         if let Some(ref schema) = args.arg_json_schema {
             let schema_json_string = load_json(schema)?;
             let schema_json = serde_json::from_str(&schema_json_string)?;
-            // First, try_is_valid the JSON Schema
-            match jsonschema::meta::try_is_valid(&schema_json) {
-                Ok(is_valid) => {
-                    if is_valid {
-                        // Now, try_validate the JSON Schema
-                        let validated = jsonschema::meta::try_validate(&schema_json);
-                        match validated {
-                            Ok(Ok(())) => {
-                                let test_validator = if args.flag_no_format_validation {
-                                    Validator::options()
-                                        .should_validate_formats(false)
-                                        .should_ignore_unknown_formats(true)
-                                        .build(&schema_json)
-                                } else {
-                                    Validator::options()
-                                        .should_validate_formats(true)
-                                        .should_ignore_unknown_formats(false)
-                                        .build(&schema_json)
-                                };
-                                if let Err(e) = test_validator {
-                                    return fail_clierror!(
-                                        "JSON Schema Format Validation Error: {e}"
-                                    );
-                                }
-                                if !args.flag_quiet {
-                                    winfo!("Valid JSON Schema.");
-                                }
-                                return Ok(());
-                            },
-                            Ok(Err(e)) => {
-                                return fail_clierror!("JSON Schema Meta-Validation Error: {e}");
-                            },
-                            Err(e) => {
-                                return fail_clierror!("JSON Schema Meta-Reference Error: {e}");
-                            },
-                        }
-                    }
-                    return fail_clierror!("Invalid JSON Schema.");
-                },
-                Err(e) => {
-                    return fail_clierror!("JSON Schema Meta-Reference Error: {e}");
-                },
+            // First, validate the JSON Schema
+            if let Err(e) = jsonschema::meta::validate(&schema_json) {
+                return fail_clierror!("JSON Schema Meta-Reference Error: {e}");
             }
+            // Now, validate the JSON Schema formats
+            let test_validator = if args.flag_no_format_validation {
+                Validator::options()
+                    .should_validate_formats(false)
+                    .should_ignore_unknown_formats(true)
+                    .build(&schema_json)
+            } else {
+                Validator::options()
+                    .should_validate_formats(true)
+                    .should_ignore_unknown_formats(false)
+                    .build(&schema_json)
+            };
+            if let Err(e) = test_validator {
+                return fail_clierror!("JSON Schema Format Validation Error: {e}");
+            }
+            if !args.flag_quiet {
+                winfo!("Valid JSON Schema.");
+            }
+            return Ok(());
         }
         return fail_clierror!("No JSON Schema file supplied.");
     }
@@ -1251,7 +1230,7 @@ pub fn run(argv: &[&str]) -> CliResult<()> {
     // parse and compile supplied JSON Schema
     let json_schema_path =
         json_schema_path.unwrap_or_else(|| PathBuf::from(json_schema_arg.as_ref().unwrap()));
-    let (schema_json, schema_compiled): (Value, Validator) =
+    let (schema_json, schema_compiled, has_unique_combined): (Value, Validator, bool) =
             // safety: we know the schema is_some() because we checked above
             match load_json(&json_schema_path.to_string_lossy()) {
             Ok(s) => {
@@ -1302,7 +1281,7 @@ pub fn run(argv: &[&str]) -> CliResult<()> {
                         }
 
                         match validator_options.build(&json) {
-                            Ok(schema) => (json, schema),
+                            Ok(schema) => (json, schema, has_unique_combined),
                             Err(e) => {
                                 return fail_clierror!(r#"Cannot compile JSONschema. error: {e}
 Try running `qsv validate schema {}` to check the JSON Schema file."#, json_schema_path.to_string_lossy());
@@ -1401,29 +1380,41 @@ Try running `qsv validate schema {}` to check the JSON Schema file."#, json_sche
                 };
 
                 // validate JSON instance against JSON Schema
-                match schema_compiled.apply(&json_instance).basic() {
-                    BasicOutput::Valid(_) => None,
-                    BasicOutput::Invalid(errors) => {
-                        // Only convert to string when we have validation errors
-                        // safety: see safety comment above
-                        let row_number_string = unsafe {
-                            simdutf8::basic::from_utf8(&record[header_len]).unwrap_unchecked()
-                        };
+                // if the schema has no stateful validators (like uniqueCombinedWith),
+                // and the record is valid, then short-circuit and return None
+                let evaluation = if !has_unique_combined && schema_compiled.is_valid(&json_instance)
+                {
+                    return None;
+                } else {
+                    // otherwise, fully evaluate the record
+                    schema_compiled.evaluate(&json_instance)
+                };
 
-                        // Preallocate the vector with the known size
-                        let mut error_messages = Vec::with_capacity(errors.len());
+                if evaluation.flag().valid {
+                    None
+                } else {
+                    // Only convert to string when we have validation errors
+                    // safety: see safety comment above
+                    let row_number_string = unsafe {
+                        simdutf8::basic::from_utf8(&record[header_len]).unwrap_unchecked()
+                    };
 
-                        // there can be multiple validation errors for a single record,
-                        // squash multiple errors into one long String with linebreaks
-                        for e in errors {
-                            error_messages.push(format!(
-                                "{row_number_string}\t{field}\t{error}",
-                                field = e.instance_location().as_str().trim_start_matches('/'),
-                                error = e.error_description()
-                            ));
-                        }
-                        Some(error_messages.join("\n"))
-                    },
+                    // Collect errors into a vector
+                    let errors: Vec<_> = evaluation.iter_errors().collect();
+
+                    // Preallocate the vector with the known size
+                    let mut error_messages = Vec::with_capacity(errors.len());
+
+                    // there can be multiple validation errors for a single record,
+                    // squash multiple errors into one long String with linebreaks
+                    for e in errors {
+                        error_messages.push(format!(
+                            "{row_number_string}\t{field}\t{error}",
+                            field = e.instance_location.as_str().trim_start_matches('/'),
+                            error = e.error
+                        ));
+                    }
+                    Some(error_messages.join("\n"))
                 }
             })
             .collect_into_vec(&mut batch_validation_results);
@@ -1436,6 +1427,7 @@ Try running `qsv validate schema {}` to check the JSON Schema file."#, json_sche
         for (i, result) in batch_validation_results.iter().enumerate() {
             if let Some(validation_error_msg) = result {
                 invalid_count += 1;
+                // safety: we know the index is in bounds because we just extended the vector
                 unsafe { valid_flags.set_unchecked(start_idx + i, false) };
                 validation_error_messages.push(validation_error_msg.to_owned());
             }
@@ -2102,19 +2094,18 @@ fn validate_json_instance(
     instance: &Value,
     schema_compiled: &Validator,
 ) -> Option<Vec<(String, String)>> {
-    match schema_compiled.apply(instance).basic() {
-        BasicOutput::Valid(_) => None,
-        BasicOutput::Invalid(errors) => Some(
-            errors
-                .iter()
-                .map(|e| {
-                    (
-                        e.instance_location().to_string(),
-                        e.error_description().to_string(),
-                    )
-                })
+    // Use is_valid() for fast boolean check on valid records (doesn't walk full tree)
+    // Only call evaluate() when invalid to get detailed errors
+    if schema_compiled.is_valid(instance) {
+        None
+    } else {
+        Some(
+            schema_compiled
+                .evaluate(instance)
+                .iter_errors()
+                .map(|e| (e.instance_location.to_string(), e.error.to_string()))
                 .collect(),
-        ),
+        )
     }
 }
 
@@ -2548,7 +2539,7 @@ fn test_dyn_enum_validator() {
         Err(e) => {
             assert_eq!(
                 format!("{e:?}"),
-                r#"ValidationError { instance: String("lanzones"), kind: Custom { message: "\"lanzones\" is not a valid dynamicEnum value" }, instance_path: Location(""), schema_path: Location("") }"#
+                r#"ValidationError { repr: ValidationErrorRepr { instance: String("lanzones"), kind: Custom { message: "\"lanzones\" is not a valid dynamicEnum value" }, instance_path: Location(""), schema_path: Location("") } }"#
             );
         },
         _ => {
