@@ -48,11 +48,11 @@ fn safenames_conditional() {
         svec!["1", "b", "33", "1", "b", "33", "34", "z", "42"],
         svec!["2", "c", "34", "3", "d", "31", "3", "y", "3.14"],
     ];
-    similar_asserts::assert_eq!(got, expected);
+    assert_eq!(got, expected);
 
     let changed_headers = wrk.output_stderr(&mut cmd);
     let expected_count = "7\n";
-    similar_asserts::assert_eq!(changed_headers, expected_count);
+    assert_eq!(changed_headers, expected_count);
 }
 
 #[test]
@@ -97,11 +97,11 @@ fn safenames_always() {
         svec!["1", "b", "33", "1", "b", "33", "34"],
         svec!["2", "c", "34", "3", "d", "31", "3"],
     ];
-    similar_asserts::assert_eq!(got, expected);
+    assert_eq!(got, expected);
 
     let changed_headers = wrk.output_stderr(&mut cmd);
     let expected_count = "6\n";
-    similar_asserts::assert_eq!(changed_headers, expected_count);
+    assert_eq!(changed_headers, expected_count);
 }
 
 #[test]
@@ -131,7 +131,7 @@ fn safenames_verify() {
 
     let changed_headers = wrk.output_stderr(&mut cmd);
     let expected_count = "6\n";
-    similar_asserts::assert_eq!(changed_headers, expected_count);
+    assert_eq!(changed_headers, expected_count);
 
     wrk.assert_success(&mut cmd);
 }
@@ -221,13 +221,10 @@ fn safenames_verify_verbose_pretty_json() {
     // the order of the duplicate headers is not guaranteed as we use a HashMap
     // so we need to check for both possible orders
     let expected = r#"{
-  "header_count": 13,
-  "duplicate_count": 2,
-  "duplicate_headers": [
-    ":4",
-    "col1:5"
-  ],
-  "unsafe_headers": [
+  "header_count": 13,"duplicate_count": 2,"duplicate_headers": [
+    "col1:5",
+    ":4"
+  ],"unsafe_headers": [
     " This is a column with invalid chars!# and leading & trailing spaces ",
     "",
     "this is already a Postgres Safe Column",
@@ -236,20 +233,16 @@ fn safenames_verify_verbose_pretty_json() {
     "",
     "",
     "_1"
-  ],
-  "safe_headers": [
+  ],"safe_headers": [
     "col1"
   ]
 }"#;
 
     let expected2 = r#"{
-  "header_count": 13,
-  "duplicate_count": 2,
-  "duplicate_headers": [
-    "col1:5",
-    ":4"
-  ],
-  "unsafe_headers": [
+  "header_count": 13,"duplicate_count": 2,"duplicate_headers": [
+    ":4",
+    "col1:5"
+  ],"unsafe_headers": [
     " This is a column with invalid chars!# and leading & trailing spaces ",
     "",
     "this is already a Postgres Safe Column",
@@ -258,13 +251,10 @@ fn safenames_verify_verbose_pretty_json() {
     "",
     "",
     "_1"
-  ],
-  "safe_headers": [
+  ],"safe_headers": [
     "col1"
   ]
 }"#;
-
-    // similar_asserts::assert_eq!(got, expected);
     assert!(got == expected || got == expected2);
 
     wrk.assert_success(&mut cmd);
@@ -376,11 +366,11 @@ fn safenames_reserved_names_default() {
         svec!["1", "b", "33", "1", "b", "33", "34"],
         svec!["2", "c", "34", "3", "d", "31", "3"],
     ];
-    similar_asserts::assert_eq!(got, expected);
+    assert_eq!(got, expected);
 
     let changed_headers = wrk.output_stderr(&mut cmd);
     let expected_count = "6\n";
-    similar_asserts::assert_eq!(changed_headers, expected_count);
+    assert_eq!(changed_headers, expected_count);
 }
 
 #[test]
@@ -420,11 +410,11 @@ fn safenames_reserved_names_specified() {
         svec!["1", "b", "33", "1", "b", "33", "34"],
         svec!["2", "c", "34", "3", "d", "31", "3"],
     ];
-    similar_asserts::assert_eq!(got, expected);
+    assert_eq!(got, expected);
 
     let changed_headers = wrk.output_stderr(&mut cmd);
     let expected_count = "6\n";
-    similar_asserts::assert_eq!(changed_headers, expected_count);
+    assert_eq!(changed_headers, expected_count);
 }
 
 #[test]
@@ -464,9 +454,9 @@ fn safenames_reserved_names_specified_case_insensitive() {
         svec!["1", "b", "33", "1", "b", "33", "34"],
         svec!["2", "c", "34", "3", "d", "31", "3"],
     ];
-    similar_asserts::assert_eq!(got, expected);
+    assert_eq!(got, expected);
 
     let changed_headers = wrk.output_stderr(&mut cmd);
     let expected_count = "6\n";
-    similar_asserts::assert_eq!(changed_headers, expected_count);
+    assert_eq!(changed_headers, expected_count);
 }
