@@ -41,7 +41,43 @@ fn to_xlsx_roundtrip() {
     cmd.arg(xlsx_file);
 
     let got: Vec<Vec<String>> = wrk.read_stdout(&mut cmd);
-    similar_asserts::assert_eq!(got, thedata);
+    assert_eq!(got, thedata);
+
+    wrk.assert_success(&mut cmd);
+}
+
+#[test]
+fn to_xlsx_roundtrip_all_strings() {
+    let wrk = Workdir::new("to_xlsx_all_strings");
+
+    let thedata = vec![
+        svec!["col1", "numbers"],
+        svec!["1", "1.23"],
+        svec!["2", "4014270163361"],
+        svec!["3", "3.14"],
+        svec!["4", "1234567890"],
+        svec!["5", "12345678901234567890"],
+        svec!["6", "123456789012345678901234567890"],
+        svec!["7", "1234567890123456789012345678901234567890"],
+    ];
+    wrk.create("in.csv", thedata.clone());
+
+    let xlsx_file = wrk.path("testxlsx.xlsx").to_string_lossy().to_string();
+    log::info!("xlsx_file: {}", xlsx_file);
+
+    let mut cmd = wrk.command("to");
+    cmd.arg("xlsx")
+        .arg("--all-strings")
+        .arg(xlsx_file.clone())
+        .arg("in.csv");
+
+    wrk.assert_success(&mut cmd);
+
+    let mut cmd = wrk.command("excel");
+    cmd.arg(xlsx_file);
+
+    let got: Vec<Vec<String>> = wrk.read_stdout(&mut cmd);
+    assert_eq!(got, thedata);
 
     wrk.assert_success(&mut cmd);
 }
@@ -86,7 +122,7 @@ fn to_xlsx_dir() {
     cmd.arg(xlsx_file.clone()).args(&["--sheet", "cities"]);
 
     let got: Vec<Vec<String>> = wrk.read_stdout(&mut cmd);
-    similar_asserts::assert_eq!(got, cities);
+    assert_eq!(got, cities);
 
     wrk.assert_success(&mut cmd);
 
@@ -94,7 +130,7 @@ fn to_xlsx_dir() {
     cmd.arg(xlsx_file).args(&["--sheet", "places"]);
 
     let got: Vec<Vec<String>> = wrk.read_stdout(&mut cmd);
-    similar_asserts::assert_eq!(got, places);
+    assert_eq!(got, places);
 
     wrk.assert_success(&mut cmd);
 }
@@ -139,7 +175,7 @@ Field Name   Field Type  Field Format
 Col1         integer     integer
 Description  string      string"#
         .to_string();
-    similar_asserts::assert_eq!(got, expected);
+    assert_eq!(got, expected);
 
     let generated_json_file = File::open(generateddp_json_path).unwrap();
     let generated_json: serde_json::Value = serde_json::from_reader(generated_json_file).unwrap();
@@ -289,7 +325,7 @@ place       string      string"#
 //         .query_map([], |row| Ok((row.get(0).unwrap(), row.get(1).unwrap())))
 //         .unwrap();
 //     let cities: Vec<(String, String)> = cities_iter.map(|r| r.unwrap()).collect();
-//     similar_asserts::assert_eq!(
+//     assert_eq!(
 //         cities,
 //         vec![
 //             (String::from("Boston"), String::from("MA")),
@@ -306,7 +342,7 @@ place       string      string"#
 //         .query_map([], |row| Ok((row.get(0).unwrap(), row.get(1).unwrap())))
 //         .unwrap();
 //     let places: Vec<(String, String)> = places_iter.map(|r| r.unwrap()).collect();
-//     similar_asserts::assert_eq!(
+//     assert_eq!(
 //         places,
 //         vec![
 //             (String::from("Boston"), String::from("Boston Garden")),
@@ -364,7 +400,7 @@ place       string      string"#
 // city        string      string
 // state       string      string"#
 //         .to_string();
-//     similar_asserts::assert_eq!(got, expected);
+//     assert_eq!(got, expected);
 
 //     let db = Connection::open(sqlite_file_filename).unwrap();
 //     let mut stmt = db.prepare("SELECT * FROM cities ORDER BY city").unwrap();
@@ -372,7 +408,7 @@ place       string      string"#
 //         .query_map([], |row| Ok((row.get(0).unwrap(), row.get(1).unwrap())))
 //         .unwrap();
 //     let cities: Vec<(String, String)> = cities_iter.map(|r| r.unwrap()).collect();
-//     similar_asserts::assert_eq!(
+//     assert_eq!(
 //         cities,
 //         vec![
 //             (String::from("Boston"), String::from("MA")),
@@ -389,7 +425,7 @@ place       string      string"#
 //         .query_map([], |row| Ok((row.get(0).unwrap(), row.get(1).unwrap())))
 //         .unwrap();
 //     let places: Vec<(String, String)> = places_iter.map(|r| r.unwrap()).collect();
-//     similar_asserts::assert_eq!(
+//     assert_eq!(
 //         places,
 //         vec![
 //             (String::from("Boston"), String::from("Boston Garden")),
@@ -403,63 +439,153 @@ place       string      string"#
 //     );
 // }
 
-// #[cfg(all(feature = "to_parquet", feature = "feature_capable"))]
-// #[test]
-// fn to_parquet_dir() {
-//     let wrk = Workdir::new("to_parquet_dir");
+#[test]
+fn to_parquet_dir() {
+    let wrk = Workdir::new("to_parquet_dir");
 
-//     let cities = vec![
-//         svec!["city", "state"],
-//         svec!["Boston", "MA"],
-//         svec!["New York", "NY"],
-//         svec!["San Francisco", "CA"],
-//         svec!["Buffalo", "NY"],
-//     ];
-//     let places = vec![
-//         svec!["city", "place"],
-//         svec!["Boston", "Logan Airport"],
-//         svec!["Boston", "Boston Garden"],
-//         svec!["Buffalo", "Ralph Wilson Stadium"],
-//         svec!["Orlando", "Disney World"],
-//     ];
+    let cities = vec![
+        svec!["city", "state"],
+        svec!["Boston", "MA"],
+        svec!["New York", "NY"],
+        svec!["San Francisco", "CA"],
+        svec!["Buffalo", "NY"],
+    ];
+    let places = vec![
+        svec!["city", "place"],
+        svec!["Boston", "Logan Airport"],
+        svec!["Boston", "Boston Garden"],
+        svec!["Buffalo", "Ralph Wilson Stadium"],
+        svec!["Orlando", "Disney World"],
+    ];
 
-//     wrk.create("cities.csv", cities.clone());
-//     wrk.create("places.csv", places.clone());
+    wrk.create("cities.csv", cities.clone());
+    wrk.create("places.csv", places.clone());
 
-//     let parquet_dir = wrk.path("test_parquet_dir");
-//     let parquet_dirname = parquet_dir.to_string_lossy().to_string();
+    let parquet_dir = wrk.path("test_parquet_dir");
+    let parquet_dirname = parquet_dir.to_string_lossy().to_string();
 
-//     let mut cmd = wrk.command("to");
-//     cmd.arg("parquet")
-//         .arg(parquet_dirname.clone())
-//         .arg("places.csv")
-//         .arg("cities.csv");
+    let mut cmd = wrk.command("to");
+    cmd.arg("parquet")
+        .arg(parquet_dirname.clone())
+        .arg("places.csv")
+        .arg("cities.csv");
 
-//     let got: String = wrk.stdout(&mut cmd);
-//     let expected: String = r#"Table 'places' (4 rows)
+    let got: String = wrk.stdout(&mut cmd);
+    let expected: String = r#"Table 'places' (4 rows)
 
-// Field Name  Field Type  Field Format
-// city        string      string
-// place       string      string
+Field Name  Field Type  Field Format
+city        string      string
+place       string      string
 
-// Table 'cities' (4 rows)
+Table 'cities' (4 rows)
 
-// Field Name  Field Type  Field Format
-// city        string      string
-// state       string      string"#
-//         .to_string();
-//     similar_asserts::assert_eq!(got, expected);
+Field Name  Field Type  Field Format
+city        string      string
+state       string      string"#
+        .to_string();
+    assert_eq!(got, expected);
 
-//     // check that the parquet files were created
-//     let files = std::fs::read_dir(parquet_dir).unwrap();
-//     let mut file_names = files
-//         .map(|f| f.unwrap().file_name().into_string().unwrap())
-//         .collect::<Vec<_>>();
-//     file_names.sort();
-//     similar_asserts::assert_eq!(file_names, vec!["cities.parquet", "places.parquet"]);
+    // check that the parquet files were created
+    let files = std::fs::read_dir(parquet_dir).unwrap();
+    let mut file_names = files
+        .map(|f| f.unwrap().file_name().into_string().unwrap())
+        .collect::<Vec<_>>();
+    file_names.sort();
+    assert_eq!(file_names, vec!["cities.parquet", "places.parquet"]);
 
-//     // TODO: check that the parquet files are valid and contain the correct data
-// }
+    // TODO: check that the parquet files are valid and contain the correct data
+}
+
+#[test]
+fn to_ods_roundtrip() {
+    let wrk = Workdir::new("to_ods");
+
+    let thedata = vec![
+        svec!["Col1", "Description"],
+        svec![
+            "1",
+            "The quick brown fox jumped over the lazy dog by the zigzag quarry site."
+        ],
+        svec!["2", "Mary had a little lamb"],
+        svec![
+            "3",
+            "I think that I shall never see a poem lovely as a tree."
+        ],
+        svec!["4", "I think, therefore I am."],
+        svec!["5", "I am a leaf on the wind."],
+        svec!["6", "Look at me, I'm the captain now."],
+        svec!["7", "Bazinga!"],
+        svec!["8", "I'm Batman."],
+    ];
+    wrk.create("in.csv", thedata.clone());
+
+    let ods_file = wrk.path("testods.ods").to_string_lossy().to_string();
+    log::info!("ods_file: {}", ods_file);
+
+    let mut cmd = wrk.command("to");
+    cmd.arg("ods").arg(ods_file.clone()).arg("in.csv");
+
+    wrk.assert_success(&mut cmd);
+
+    let mut cmd = wrk.command("excel");
+    cmd.arg(ods_file);
+
+    let got: Vec<Vec<String>> = wrk.read_stdout(&mut cmd);
+    assert_eq!(got, thedata);
+
+    wrk.assert_success(&mut cmd);
+}
+
+#[test]
+fn to_ods_dir() {
+    let wrk = Workdir::new("to_ods_dir");
+
+    // Create test files
+    let file1_data = vec![
+        svec!["Col1", "Description"],
+        svec!["1", "First file data"],
+        svec!["2", "More data"],
+    ];
+    wrk.create("file1.csv", file1_data.clone());
+
+    let file2_data = vec![
+        svec!["Col1", "Description"],
+        svec!["3", "Second file data"],
+        svec!["4", "Even more data"],
+    ];
+    wrk.create("file2.csv", file2_data.clone());
+
+    // Create a single ODS file that will contain both sheets
+    let ods_file = wrk.path("testods.ods").to_string_lossy().to_string();
+    log::info!("ods_file: {}", ods_file);
+
+    // Convert files to ODS
+    let mut cmd = wrk.command("to");
+    cmd.arg("ods")
+        .arg(ods_file.clone())
+        .arg("file1.csv")
+        .arg("file2.csv");
+
+    wrk.assert_success(&mut cmd);
+
+    // Verify the content of the first sheet
+    let mut cmd = wrk.command("excel");
+    cmd.arg(ods_file.clone()).args(&["--sheet", "file1"]);
+
+    let got: Vec<Vec<String>> = wrk.read_stdout(&mut cmd);
+    assert_eq!(got, file1_data);
+
+    wrk.assert_success(&mut cmd);
+
+    // Verify the content of the second sheet
+    let mut cmd = wrk.command("excel");
+    cmd.arg(ods_file).args(&["--sheet", "file2"]);
+
+    let got: Vec<Vec<String>> = wrk.read_stdout(&mut cmd);
+    assert_eq!(got, file2_data);
+
+    wrk.assert_success(&mut cmd);
+}
 
 // #[test]
 // #[ignore = "Testing postgres support requires a running, properly configured postgres server, \
@@ -505,7 +631,7 @@ place       string      string"#
 // city        string      string
 // state       string      string"#
 //         .to_string();
-//     similar_asserts::assert_eq!(got, expected);
+//     assert_eq!(got, expected);
 
 //     let mut client =
 //         Client::connect("postgres://testuser:test123@localhost/testdb", NoTls).unwrap();
@@ -518,7 +644,7 @@ place       string      string"#
 //         let state: String = row.get(1);
 //         cities_result.push((city, state));
 //     }
-//     similar_asserts::assert_eq!(
+//     assert_eq!(
 //         cities_result,
 //         vec![
 //             (String::from("Boston"), String::from("MA")),
@@ -537,7 +663,7 @@ place       string      string"#
 //         let place: String = row.get(1);
 //         places_result.push((city, place));
 //     }
-//     similar_asserts::assert_eq!(
+//     assert_eq!(
 //         places_result,
 //         vec![
 //             (String::from("Boston"), String::from("Boston Garden")),
